==> geolocator-5.1.4.tar.gz: android/src/main/java/com/baseflow/geolocator/data/AddressMapper.java <==
package com.baseflow.geolocator.data;

import android.location.Address;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class AddressMapper {

  public static List<Map<String, Object>> toHashMapList(List<Address> addresses) {
    List<Map<String, Object>> hashMaps = new ArrayList<>(addresses.size());

    for (Address address : addresses) {
      Map<String, Object> hashMap = AddressMapper.toHashMap(address);
      hashMaps.add(hashMap);
    }

    return hashMaps;
  }

  private static Map<String, Object> toHashMap(Address address) {
    Map<String, Object> placemark = new HashMap<>();

    placemark.put("name", address.getFeatureName());
    placemark.put("isoCountryCode", address.getCountryCode());
    placemark.put("country", address.getCountryName());
    placemark.put("thoroughfare", address.getThoroughfare());
    placemark.put("subThoroughfare", address.getSubThoroughfare());
    placemark.put("postalCode", address.getPostalCode());
    placemark.put("administrativeArea", address.getAdminArea());
    placemark.put("subAdministrativeArea", address.getSubAdminArea());
    placemark.put("locality", address.getLocality());
    placemark.put("subLocality", address.getSubLocality());

    if (address.hasLatitude() && address.hasLongitude()) {
      Map<String, Double> locationMap = new HashMap<>();

      locationMap.put("latitude", address.getLatitude());
      locationMap.put("longitude", address.getLongitude());

      placemark.put("location", locationMap);
    }

    return placemark;
  }
}

==> geolocator-5.3.2.tar.gz: android/src/main/java/com/baseflow/geolocator/data/AddressMapper.java <==
package com.baseflow.geolocator.data;

import android.location.Address;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class AddressMapper {

  public static List<Map<String, Object>> toHashMapList(List<Address> addresses) {
    List<Map<String, Object>> hashMaps = new ArrayList<>(addresses.size());

    for (Address address : addresses) {
      Map<String, Object> hashMap = AddressMapper.toHashMap(address);
      hashMaps.add(hashMap);
    }

    return hashMaps;
  }

  private static Map<String, Object> toHashMap(Address address) {
    Map<String, Object> placemark = new HashMap<>();

    placemark.put("name", address.getFeatureName());
    placemark.put("isoCountryCode", address.getCountryCode());
    placemark.put("country", address.getCountryName());
    placemark.put("thoroughfare", address.getThoroughfare());
    placemark.put("subThoroughfare", address.getSubThoroughfare());
    placemark.put("postalCode", address.getPostalCode());
    placemark.put("administrativeArea", address.getAdminArea());
    placemark.put("subAdministrativeArea", address.getSubAdminArea());
    placemark.put("locality", address.getLocality());
    placemark.put("subLocality", address.getSubLocality());

    if (address.hasLatitude() && address.hasLongitude()) {
      Map<String, Double> positionMap = new HashMap<>();

      positionMap.put("latitude", address.getLatitude());
      positionMap.put("longitude", address.getLongitude());

      placemark.put("position", positionMap);
    }

    return placemark;
  }
}
